==> qtjambi-bluetooth-debuginfo-macos-5.15.18.jar: sources/QtJambiBluetooth/QBluetoothLocalDevice_shell.h <==
#ifndef QBLUETOOTHLOCALDEVICE_SHELL_H
#define QBLUETOOTHLOCALDEVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtBluetooth/qbluetoothlocaldevice.h>
#include <QtJambi/QtJambiAPI>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothhostinfo.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QBluetoothLocalDevice_shell : public QBluetoothLocalDevice, public QtJambiShellInterface
{
public:
    QBluetoothLocalDevice_shell(const QBluetoothAddress& address0, QObject* parent1 = nullptr);
    QBluetoothLocalDevice_shell(QObject* parent0 = nullptr);
    ~QBluetoothLocalDevice_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBluetoothLocalDevice_access : public QBluetoothLocalDevice
{
};

#endif // QBLUETOOTHLOCALDEVICE_SHELL_H

==> qtjambi-bluetooth-debuginfo-macos-6.5.3.jar: sources/QtJambiBluetooth/QBluetoothLocalDevice_shell.h <==
#ifndef QBLUETOOTHLOCALDEVICE_SHELL_H
#define QBLUETOOTHLOCALDEVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtBluetooth/qbluetoothlocaldevice.h>
#include <QtJambi/QtJambiAPI>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothhostinfo.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QBluetoothLocalDevice_shell : public QBluetoothLocalDevice, public QtJambiShellInterface
{
public:
    QBluetoothLocalDevice_shell(QObject* parent0 = nullptr);
    QBluetoothLocalDevice_shell(const QBluetoothAddress& address0, QObject* parent1 = nullptr);
    ~QBluetoothLocalDevice_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBluetoothLocalDevice_access : public QBluetoothLocalDevice
{
};

#endif // QBLUETOOTHLOCALDEVICE_SHELL_H
